@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,9 +11,9 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from ..core.abstractcontroller import AbstractBaseController
-from ..resources.strings import strings, flag_text
-from ..operations import listops
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.resources.strings import strings, flag_text
+from ebcli.operations import listops
 
 
 class ListController(AbstractBaseController):
@@ -28,8 +28,6 @@ class ListController(AbstractBaseController):
 
     def do_command(self):
         all_apps = self.app.pargs.all
-        # No need to get app name if all flag is present
-        ## By not getting it, we can do a list in a non-initialized location
         if not all_apps:
             app_name = self.get_app_name()
         else:
@@ -37,7 +35,3 @@ class ListController(AbstractBaseController):
         verbose = self.app.pargs.verbose
 
         listops.list_env_names(app_name, verbose, all_apps)
-
-    def complete_command(self, commands):
-        # We only care about regions
-        self.complete_region(commands)
\ No newline at end of file
