@@ -1,4 +1,4 @@
-# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,8 +11,8 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from .. core import io
-from . import term
+from ebcli. core import io
+from ebcli.display import term
 
 from cement.utils.misc import minimal_logger
 
@@ -22,9 +22,7 @@ LOG = minimal_logger(__name__)
 class Table(object):
     def __init__(self, name, columns=None, screen=None):
         self.name = name
-        if columns is None:
-            columns = {}
-        self.columns = columns
+        self.columns = columns or []
         self.visible = True
         self.data = None
         self.width = None
@@ -45,7 +43,6 @@ class Table(object):
         self.set_data(table_data)
         self.visible_rows = num_of_rows
         if self.vertical_offset > self.get_max_offset():
-            # Adjust for changing size of data
             self.vertical_offset = self.get_max_offset()
         self.first_column = min(self.screen.horizontal_offset + 1,
                                 len(self.columns) - 1)
@@ -61,7 +58,6 @@ class Table(object):
     MAX_DESCRIPTION = 100
 
     def draw_header_row(self):
-        # Print headers
         t = term.get_terminal()
         labels = [' ']
         width = self.width
@@ -70,15 +66,16 @@ class Table(object):
             column_size = column.size
             if column_size is None:
                 column_size = self.get_widest_data_length_in_column(self.columns[c]) + 2
-                # special case for Description column this should be the same for all description columns, allows very
-                #   large descriptions that we are able to scroll through.
+                # special case for Description column this should be the same for all
+                # description columns, allows very large descriptions that we are able
+                # to scroll through.
                 if column.name == 'Description' and column_size > self.MAX_DESCRIPTION:
                     column_size = self.MAX_DESCRIPTION
                 column.fit_size = column_size
             header = justify_and_trim(column.name, column_size, column.justify)
-            if (self.screen.sort_index and  # We are sorting
+            if (self.screen.sort_index and
                     self.screen.sort_index[1] == c and  # Sort column
-                    self.name == self.screen.sort_index[0] and # sort table
+                    self.name == self.screen.sort_index[0] and  # sort table
                     len(' '.join(labels)) < width):  # Column is on screen
                 format_string = '{n}{b}{u}{data}{n}{r}'
                 header = format_string.replace('{data}', header)
@@ -223,7 +220,7 @@ class Table(object):
     def get_row_id(self, row_index):
         try:
             row = self.data[row_index]
-        except IndexError as e:
+        except IndexError:
             raise IndexError('Can not access index:{}'.format(row_index))
         return row.get('InstanceId')
 
@@ -267,7 +264,4 @@ class Column(object):
         self.fit_size = size
         self.key = key
         self.justify = justify
-        if sort_key:
-            self.sort_key = sort_key
-        else:
-            self.sort_key = self.key
+        self.sort_key = sort_key or self.key
