@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -14,14 +14,16 @@
 import os
 import shutil
 
-from ..core.abstractcontroller import AbstractBaseController
-from ..resources.strings import strings, flag_text
-from ..core import io, fileoperations
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.resources.strings import strings, flag_text
+from ebcli.core import io, fileoperations
 
 
 CWFILES_DIRNAME = 'cloudwatchfiles'
-CWFILES_DIR_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)),
-                                                CWFILES_DIRNAME)
+CWFILES_DIR_PATH = os.path.join(os.path.dirname(
+    os.path.realpath(__file__)),
+    CWFILES_DIRNAME
+)
 
 
 class CloudWatchSetUp(AbstractBaseController):
@@ -66,4 +68,4 @@ def remove_cwl_extensions(cwfile_dir, ebextension_dir):
         except:
             io.log_warning('Ebextension {} already removed'.format(file_name))
 
-    io.echo(strings['cloudwatch-setup.removetext'])
\ No newline at end of file
+    io.echo(strings['cloudwatch-setup.removetext'])
