@@ -65,5 +65,19 @@ def get_target_groups_for_load_balancer(load_balancer_arn):
         raise NotFoundError(e)
 
 
+def get_listeners_for_load_balancer(load_balancer_arn):
+    return _make_api_call(
+            'describe_listeners',
+            LoadBalancerArn=load_balancer_arn
+        )
+
+
+def describe_load_balancers(load_balancer_name):
+    return _make_api_call(
+            'describe_load_balancers',
+            Names=load_balancer_name
+        )
+
+
 def _sleep_to_prevent_elbv2_throttling():
     time.sleep(0.5)
