@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,8 +11,8 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from ..lib import elasticbeanstalk
-from ..core import io
+from ebcli.lib import elasticbeanstalk
+from ebcli.core import io
 
 
 def get_abortable_envs(app_name):
@@ -21,7 +21,6 @@ def get_abortable_envs(app_name):
 
 
 def abort_operation(env_name):
-    request_id = elasticbeanstalk.abort_environment_update(env_name)
+    elasticbeanstalk.abort_environment_update(env_name)
     io.echo('Aborting update to environment "{}". \n'
             'Type "eb events -f" to watch the environment events.'.format(env_name))
-    # io.echo(request_id)
\ No newline at end of file
