@@ -12,19 +12,63 @@
 # language governing permissions and limitations under the License.
 from cement.utils.misc import minimal_logger
 
-from ebcli.core import io
+from ebcli.core import io, fileoperations
 from ebcli.display.appversion import term, VersionScreen, VersionDataPoller
 from ebcli.display.table import Table, Column
 from ebcli.display.help import ViewlessHelpTable
 from ebcli.lib import elasticbeanstalk as elasticbeanstalk
 from ebcli.objects.exceptions import ValidationError, NotFoundError
+from ebcli.operations import commonops, gitops, buildspecops
 from ebcli.resources.strings import prompts, strings
 
 LOG = minimal_logger(__name__)
 
 
-def delete_app_version_label(app_name, version_label):
+def create_app_version_without_deployment(app_name, label=None,
+                                          staged=False, process=False, description=None, source=None, timeout=5):
+    build_config = None
+    if fileoperations.build_spec_exists():
+        build_config = fileoperations.get_build_configuration()
+        LOG.debug("Retrieved build configuration from buildspec: {0}".format(build_config.__str__()))
 
+    if source is not None:
+        app_version_label = commonops.create_app_version_from_source(
+            app_name,
+            source,
+            process=process,
+            label=label,
+            message=description,
+            build_config=build_config
+        )
+        io.echo("Creating application version via specified source.")
+        process = True
+    elif gitops.git_management_enabled() and not staged:
+        app_version_label = commonops.create_codecommit_app_version(
+            app_name, process=process, label=label, message=description, build_config=build_config)
+        io.echo("Creating application version via CodeCommit.")
+        process = True
+    else:
+        app_version_label = commonops.create_app_version(
+            app_name,
+            process=process,
+            label=label,
+            message=description,
+            staged=staged,
+            build_config=build_config
+        )
+
+    if build_config is not None:
+        buildspecops.stream_build_configuration_app_version_creation(
+            app_name, app_version_label, build_config)
+    elif process is True:
+        commonops.wait_for_processed_app_versions(
+            app_name,
+            [app_version_label],
+            timeout=timeout
+        )
+
+
+def delete_app_version_label(app_name, version_label):
     if version_label:
         app_versions = elasticbeanstalk.get_application_versions(app_name)['ApplicationVersions']
         if not any(version_label == app_version['VersionLabel'] for app_version in app_versions):
