@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -30,14 +30,24 @@ def validate_restore(env_id):
     """
     Do client side validation because rebuild will rebuild a running environments as well
     """
-    env = elasticbeanstalk.get_environment(env_id=env_id, include_deleted=True, deleted_back_to=get_date_cutoff())
+    env = elasticbeanstalk.get_environment(
+        env_id=env_id,
+        include_deleted=True,
+        deleted_back_to=get_date_cutoff()
+    )
 
     if env.status != 'Terminated':
-        raise InvalidParameterValueError('Environment {0} ({1}) is currently {2}, must be "Terminated" to restore'
-                                         .format(env.name, env.id, env.status))
+        raise InvalidParameterValueError(
+            'Environment {0} ({1}) is currently {2}, must '
+            'be "Terminated" to restore'.format(
+                env.name,
+                env.id,
+                env.status
+            )
+        )
 
 
-def restore(env_id):
+def restore(env_id, timeout=None):
     validate_restore(env_id)
     try:
         request_id = elasticbeanstalk.rebuild_environment(env_id=env_id)
@@ -45,14 +55,18 @@ def restore(env_id):
         message = e.message.replace('rebuild', 'restore')
         raise InvalidParameterValueError(message)
 
-    commonops.wait_for_success_events(request_id, timeout_in_minutes=None, can_abort=True)
+    commonops.wait_for_success_events(request_id, timeout_in_minutes=timeout, can_abort=True)
 
 
 def get_restorable_envs(app_name):
     date_cutoff = get_date_cutoff()
     environments = []
 
-    app_envs = elasticbeanstalk.get_raw_app_environments(app_name, include_deleted=True, deleted_back_to=date_cutoff)
+    app_envs = elasticbeanstalk.get_raw_app_environments(
+        app_name,
+        include_deleted=True,
+        deleted_back_to=date_cutoff
+    )
     for env in app_envs:
         if env['Status'] == 'Terminated':
             environments.append(env)
