@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,11 +11,11 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 from ebcli.objects.platform import PlatformVersion
-from ..resources.strings import prompts
-from ..resources.statics import namespaces, option_names
-from ..core import io
-from ..lib import elasticbeanstalk
-from . import commonops, solution_stack_ops
+from ebcli.resources.strings import prompts
+from ebcli.resources.statics import namespaces, option_names
+from ebcli.core import io
+from ebcli.lib import elasticbeanstalk
+from ebcli.operations import commonops, solution_stack_ops
 
 
 def _get_warning_message(confirm, single, rolling_enabled, webserver, noroll):
@@ -75,13 +75,12 @@ def upgrade_env(app_name, env_name, timeout, confirm, noroll):
             io.echo()
 
         if not confirm:
-            # Get confirmation
             io.validate_action(prompts['upgrade.validate'], env.name)
 
         add_rolling = _should_add_rolling(single, rolling_enabled, noroll)
 
         do_upgrade(env_name, add_rolling, timeout, latest.name,
-                   health_based=webserver, platform_arn = latest.name)
+                   health_based=webserver, platform_arn=latest.name)
 
 
 def do_upgrade(env_name, add_rolling, timeout, solution_stack_name,
@@ -112,4 +111,4 @@ def do_upgrade(env_name, add_rolling, timeout, solution_stack_name,
     else:
         commonops.update_environment(
             env_name, changes, None, timeout=timeout,
-            solution_stack_name=solution_stack_name)
\ No newline at end of file
+            solution_stack_name=solution_stack_name)
